@@ -545,9 +545,9 @@ xml_new_source_node (GbfAmProject *project,
 	xmlNodePtr source;
 	gchar *filename;
 	
-	source = xmlNewDocNode (doc, NULL, "source", NULL);
+	source = xmlNewDocNode (doc, NULL, BAD_CAST "source", NULL);
 	filename = uri_get_chrooted_path (project->project_root_uri, uri);
-	xmlSetProp (source, "uri", filename);
+	xmlSetProp (source, BAD_CAST "uri", BAD_CAST filename);
 	g_free (filename);
 	
 	return source;
@@ -569,17 +569,17 @@ xml_write_location_recursive (GbfAmProject *project,
 		GbfAmNode *node = GBF_AM_NODE (g_node);
 		switch (node->type) {
 			case GBF_AM_NODE_GROUP:
-				xml_node = xmlNewDocNode (doc, NULL, "group", NULL);
-				xmlSetProp (xml_node, "id", node->id);
+				xml_node = xmlNewDocNode (doc, NULL, BAD_CAST "group", NULL);
+				xmlSetProp (xml_node, BAD_CAST "id", BAD_CAST node->id);
 				finished = TRUE;
 				break;
 			case GBF_AM_NODE_TARGET:
-				xml_node = xmlNewDocNode (doc, NULL, "target", NULL);
+				xml_node = xmlNewDocNode (doc, NULL, BAD_CAST "target", NULL);
 				/* strip the group id from the target
 				   id, since the script identifies
 				   targets only within the group */
-				xmlSetProp (xml_node, "id",
-					    node->id +
+				xmlSetProp (xml_node, BAD_CAST "id",
+					    BAD_CAST node->id +
 					    strlen (GBF_AM_NODE (g_node->parent)->id));
 				break;
 			case GBF_AM_NODE_SOURCE:
@@ -615,8 +615,8 @@ xml_write_add_source (GbfAmProject *project,
 {
 	xmlNodePtr cur, source;
 	
-	cur = xmlNewDocNode (doc, NULL, "add", NULL);
-	xmlSetProp (cur, "type", "source");
+	cur = xmlNewDocNode (doc, NULL, BAD_CAST "add", NULL);
+	xmlSetProp (cur, BAD_CAST "type", BAD_CAST "source");
 	xmlAddChild (doc->children, cur);
 
 	cur = xml_write_location_recursive (project, doc, cur, g_node);
@@ -633,8 +633,8 @@ xml_write_remove_source (GbfAmProject *project,
 {
 	xmlNodePtr cur;
 
-	cur = xmlNewDocNode (doc, NULL, "remove", NULL);
-	xmlSetProp (cur, "type", "source");
+	cur = xmlNewDocNode (doc, NULL, BAD_CAST "remove", NULL);
+	xmlSetProp (cur, BAD_CAST "type", BAD_CAST "source");
 	xmlAddChild (doc->children, cur);
 	
 	cur = xml_write_location_recursive (project, doc, cur, g_node);
@@ -653,15 +653,15 @@ xml_write_add_target (GbfAmProject *project,
 	
 	g_assert (GBF_AM_NODE (g_node)->type == GBF_AM_NODE_GROUP);
 
-	cur = xmlNewDocNode (doc, NULL, "add", NULL);
-	xmlSetProp (cur, "type", "target");
+	cur = xmlNewDocNode (doc, NULL, BAD_CAST "add", NULL);
+	xmlSetProp (cur, BAD_CAST "type", BAD_CAST "target");
 	xmlAddChild (doc->children, cur);
 
 	cur = xml_write_location_recursive (project, doc, cur, g_node);
 	
-	target = xmlNewDocNode (doc, NULL, "target", NULL);
-	xmlSetProp (target, "id", name);
-	xmlSetProp (target, "type", type);
+	target = xmlNewDocNode (doc, NULL, BAD_CAST "target", NULL);
+	xmlSetProp (target, BAD_CAST "id", BAD_CAST name);
+	xmlSetProp (target, BAD_CAST "type", BAD_CAST type);
 	xmlAddChild (cur, target);
 
 	return TRUE;
@@ -681,14 +681,14 @@ xml_write_set_item_config_cb (const gchar *param, GbfAmConfigValue *value,
 	GbfXmlWriteData *data = (GbfXmlWriteData*)user_data;
 	
 	if (value->type == GBF_AM_TYPE_STRING) {
-		GbfAmConfigValue *old_value;
+		GbfAmConfigValue *old_value = NULL;
 		const gchar *old_str = "", *new_str = "";
 		
 		new_str = gbf_am_config_value_get_string (value);
 		if (new_str == NULL)
 			new_str = "";
-		
-		old_value = gbf_am_config_mapping_lookup (data->old_config, param);
+		if (data->old_config)
+			old_value = gbf_am_config_mapping_lookup (data->old_config, param);
 		if (old_value) {
 			old_str = gbf_am_config_value_get_string (old_value);
 			if (old_str == NULL)
@@ -697,9 +697,9 @@ xml_write_set_item_config_cb (const gchar *param, GbfAmConfigValue *value,
 		if (strcmp (new_str, old_str) != 0)
 		{
 			param_node = xmlNewDocNode (data->doc, NULL,
-						    "item", NULL);
-			xmlSetProp (param_node, "name", param);
-			xmlSetProp (param_node, "value", new_str);
+						    BAD_CAST "item", NULL);
+			xmlSetProp (param_node, BAD_CAST "name", BAD_CAST param);
+			xmlSetProp (param_node, BAD_CAST "value", BAD_CAST new_str);
 			xmlAddChild (data->curr_xml_node, param_node);
 		}
 	}
@@ -729,29 +729,30 @@ xml_write_set_param_config_cb (const gchar *param, GbfAmConfigValue *value,
 		if (strcmp (new_str, old_str) != 0)
 		{
 			param_node = xmlNewDocNode (data->doc, NULL,
-						    "param", NULL);
-			xmlSetProp (param_node, "name", param);
-			xmlSetProp (param_node, "value", new_str);
+						    BAD_CAST "param", NULL);
+			xmlSetProp (param_node, BAD_CAST "name", BAD_CAST param);
+			xmlSetProp (param_node, BAD_CAST "value", BAD_CAST new_str);
 			xmlAddChild (data->curr_xml_node, param_node);
 		}
 	} else if (value->type == GBF_AM_TYPE_LIST) {
 		param_node = xmlNewDocNode (data->doc, NULL,
-					    "param", NULL);
-		xmlSetProp (param_node, "name", param);
+					    BAD_CAST "param", NULL);
+		xmlSetProp (param_node, BAD_CAST "name", BAD_CAST param);
 		/* FIXME */
 	} else if (value->type == GBF_AM_TYPE_MAPPING) {
 		
 		GbfXmlWriteData write_data;
-		GbfAmConfigValue *old_value;
-		GbfAmConfigMapping *new_mapping, *old_mapping;
+		GbfAmConfigValue *old_value = NULL;
+		GbfAmConfigMapping *new_mapping = NULL, *old_mapping = NULL;
 		
 		new_mapping = gbf_am_config_value_get_mapping (value);
 		old_value = gbf_am_config_mapping_lookup (data->old_config, param);
-		old_mapping = gbf_am_config_value_get_mapping (old_value);
+		if (old_value)
+			old_mapping = gbf_am_config_value_get_mapping (old_value);
 		
-		param_node = xmlNewDocNode (data->doc, NULL, "param", NULL);
+		param_node = xmlNewDocNode (data->doc, NULL, BAD_CAST "param", NULL);
 		
-		xmlSetProp (param_node, "name", param);
+		xmlSetProp (param_node, BAD_CAST "name", BAD_CAST param);
 		
 		write_data.doc = data->doc;
 		write_data.curr_xml_node = param_node;
@@ -778,19 +779,19 @@ xml_write_set_config (GbfAmProject       *project,
 	xmlNodePtr cur, config;
 	GbfXmlWriteData user_data;
 	
-	cur = xmlNewDocNode (doc, NULL, "set", NULL);
-	xmlSetProp (cur, "type", "config");
+	cur = xmlNewDocNode (doc, NULL, BAD_CAST "set", NULL);
+	xmlSetProp (cur, BAD_CAST "type", BAD_CAST "config");
 	xmlAddChild (doc->children, cur);
 
 	if (g_node)
 		cur = xml_write_location_recursive (project, doc, cur, g_node);
 	
-	config = xmlNewDocNode (doc, NULL, "config", NULL);
+	config = xmlNewDocNode (doc, NULL, BAD_CAST "config", NULL);
 	xmlAddChild (cur, config);
 	
 	user_data.doc = doc;
 	user_data.curr_xml_node = config;
-	user_data.old_config = GBF_AM_NODE (g_node)->config;
+	user_data.old_config = g_node? GBF_AM_NODE (g_node)->config : project->project_config;
 	
 	gbf_am_config_mapping_foreach (new_config,
 				       xml_write_set_param_config_cb,
@@ -808,8 +809,8 @@ xml_write_remove_target (GbfAmProject *project,
 {
 	xmlNodePtr cur;
 
-	cur = xmlNewDocNode (doc, NULL, "remove", NULL);
-	xmlSetProp (cur, "type", "target");
+	cur = xmlNewDocNode (doc, NULL, BAD_CAST "remove", NULL);
+	xmlSetProp (cur, BAD_CAST "type", BAD_CAST "target");
 	xmlAddChild (doc->children, cur);
 	
 	cur = xml_write_location_recursive (project, doc, cur, g_node);
@@ -828,15 +829,15 @@ xml_write_add_group (GbfAmProject *project,
 	
 	g_assert (GBF_AM_NODE (g_node)->type == GBF_AM_NODE_GROUP);
 
-	cur = xmlNewDocNode (doc, NULL, "add", NULL);
-	xmlSetProp (cur, "type", "group");
+	cur = xmlNewDocNode (doc, NULL, BAD_CAST "add", NULL);
+	xmlSetProp (cur, BAD_CAST "type", BAD_CAST "group");
 	xmlAddChild (doc->children, cur);
 
 	/* calculate new id needed by the script */
 	new_id = g_strdup_printf ("%s%s/", GBF_AM_NODE (g_node)->id, new_group);
 	
-	group = xmlNewDocNode (doc, NULL, "group", NULL);
-	xmlSetProp (group, "id", new_id);
+	group = xmlNewDocNode (doc, NULL, BAD_CAST "group", NULL);
+	xmlSetProp (group, BAD_CAST "id", BAD_CAST new_id);
 	xmlAddChild (cur, group);
 	g_free (new_id);
 	
@@ -850,8 +851,8 @@ xml_write_remove_group (GbfAmProject *project,
 {
 	xmlNodePtr cur;
 
-	cur = xmlNewDocNode (doc, NULL, "remove", NULL);
-	xmlSetProp (cur, "type", "group");
+	cur = xmlNewDocNode (doc, NULL, BAD_CAST "remove", NULL);
+	xmlSetProp (cur, BAD_CAST "type", BAD_CAST "group");
 	xmlAddChild (doc->children, cur);
 	
 	cur = xml_write_location_recursive (project, doc, cur, g_node);
@@ -864,12 +865,12 @@ xml_new_change_doc (GbfAmProject *project)
 {
 	xmlDocPtr doc;
 	
-	doc = xmlNewDoc ("1.0");
+	doc = xmlNewDoc (BAD_CAST "1.0");
 	if (doc != NULL) {
 		gchar *root_path;
 		root_path = uri_to_path (project->project_root_uri);
-		doc->children = xmlNewDocNode (doc, NULL, "project", NULL);
-		xmlSetProp (doc->children, "root", root_path);
+		doc->children = xmlNewDocNode (doc, NULL, BAD_CAST "project", NULL);
+		xmlSetProp (doc->children, BAD_CAST "root", BAD_CAST root_path);
 		g_free (root_path);
 	}
 
@@ -1132,7 +1133,7 @@ sax_start_element (void *ctxt, const xmlChar *name, const xmlChar **attrs)
 		/* assign here, since we destroy the data in project_data_init() */
 		if (project_file) {
 			g_free (project->project_file);
-			project->project_file = g_strdup (project_file);
+			project->project_file = g_strdup ((char *) project_file);
 		}
 		
 	} else if (xmlStrEqual (name, BAD_CAST "group")) {
@@ -1168,7 +1169,7 @@ sax_start_element (void *ctxt, const xmlChar *name, const xmlChar **attrs)
 			g_node = project_node_new (GBF_AM_NODE_GROUP);
 			node = GBF_AM_NODE (g_node);
 			
-			node->id = g_strdup (group_id);
+			node->id = g_strdup ((char *) group_id);
 			
 			/* set parent group */
 			if (data->current_node != NULL) {
@@ -1216,8 +1217,8 @@ sax_start_element (void *ctxt, const xmlChar *name, const xmlChar **attrs)
 				child = g_node_next_sibling (child);
 			}
 		}
-		node->name = g_strdup (group_name);
-		node->uri = g_strdup (group_source);
+		node->name = g_strdup ((char *) group_name);
+		node->uri = g_strdup ((char *) group_source);
 		node->config = gbf_am_config_mapping_new ();
 		
 		/* set working node */
@@ -1297,8 +1298,8 @@ sax_start_element (void *ctxt, const xmlChar *name, const xmlChar **attrs)
 				child = g_node_next_sibling (child);
 			}
 		}
-		node->name = g_strdup (target_name);
-		node->detail = g_strdup (target_type);
+		node->name = g_strdup ((char *) target_name);
+		node->detail = g_strdup ((char *) target_type);
 		node->config = gbf_am_config_mapping_new ();
 
 		/* set working node */
@@ -1423,7 +1424,7 @@ sax_start_element (void *ctxt, const xmlChar *name, const xmlChar **attrs)
 			g_free (node->detail);
 		}
 		node->uri = source_uri;
-		node->detail = g_strdup (target_dep);
+		node->detail = g_strdup ((char *) target_dep);
 
 		/* set working node */
 		data->current_node = g_node;
@@ -1477,11 +1478,11 @@ sax_start_element (void *ctxt, const xmlChar *name, const xmlChar **attrs)
 
 			/* save scalar string parameter */
 			param = gbf_am_config_value_new (GBF_AM_TYPE_STRING);
-			gbf_am_config_value_set_string (param, param_value);
+			gbf_am_config_value_set_string (param, (char *) param_value);
 
 			/* try to save the parameter in the config mapping */
 			if (!gbf_am_config_mapping_insert (data->config,
-							   param_name, param)) {
+							   (char *) param_name, param)) {
 				gbf_am_config_value_free (param);
 			}
 
@@ -1490,7 +1491,7 @@ sax_start_element (void *ctxt, const xmlChar *name, const xmlChar **attrs)
 
 		} else {
 			/* we expect a list or a hash of values */
-			data->param_key = g_strdup (param_name);
+			data->param_key = g_strdup ((char *) param_name);
 			data->state = PARSE_PARAM;
 		}
 		
@@ -1520,7 +1521,7 @@ sax_start_element (void *ctxt, const xmlChar *name, const xmlChar **attrs)
 		
 		/* create item value */
 		item = gbf_am_config_value_new (GBF_AM_TYPE_STRING);
-		gbf_am_config_value_set_string (item, item_value);
+		gbf_am_config_value_set_string (item, (char *) item_value);
 		
 		/* get current configuration parameter */
 		param = gbf_am_config_mapping_lookup (data->config, data->param_key);
@@ -1548,7 +1549,7 @@ sax_start_element (void *ctxt, const xmlChar *name, const xmlChar **attrs)
 		    case GBF_AM_TYPE_MAPPING:
 			    if (item_name == NULL ||
 				!gbf_am_config_mapping_insert (param->mapping,
-							       item_name,
+							       (char *) item_name,
 							       item)) {
 				    gbf_am_config_value_free (item);
 			    }
@@ -1919,7 +1920,7 @@ spawn_write_child (GIOChannel *ioc, GIOCondition condition, gpointer user_data)
 
 		switch (status) {
 		    case G_IO_STATUS_NORMAL:
-			    DEBUG (g_message ("wrote %d bytes", bytes_written));
+			    DEBUG (g_message ("wrote %" G_GSIZE_FORMAT " bytes", bytes_written));
 			    
 			    if (data->input.length < data->input.size) {
 				    /* don't remove the source */
@@ -2270,7 +2271,7 @@ project_update (GbfAmProject *project,
 	gboolean retval;
 	gint i;
 	xmlChar *xml_doc;
-	int xml_size;
+	gint xml_size;
 	
 	/* remove file monitors */
 	monitors_remove (project);
@@ -2289,7 +2290,7 @@ project_update (GbfAmProject *project,
 
 	/* execute the script */
 	data = spawn_script (argv, SCRIPT_TIMEOUT,
-			     xml_doc, xml_size,  /* input buffer */
+			     (char *) xml_doc, xml_size,  /* input buffer */
 			     NULL, NULL, NULL);  /* i/o callbacks */
 	xmlFree (xml_doc);
 
@@ -3074,7 +3075,7 @@ impl_remove_group (GbfProject  *_project,
 	doc = xml_new_change_doc (project);
 	if (!xml_write_remove_group (project, doc, g_node)) {
 		error_set (error, GBF_PROJECT_ERROR_DOESNT_EXIST,
-			   _("Group coudn't be removed"));
+			   _("Group couldn't be removed"));
 		xmlFreeDoc (doc);
 		return;
 	}
@@ -3297,7 +3298,7 @@ impl_remove_target (GbfProject  *_project,
 	doc = xml_new_change_doc (project);
 	if (!xml_write_remove_target (project, doc, g_node)) {
 		error_set (error, GBF_PROJECT_ERROR_DOESNT_EXIST,
-			   _("Target coudn't be removed"));
+			   _("Target couldn't be removed"));
 		xmlFreeDoc (doc);
 		return;
 	}
@@ -3334,6 +3335,10 @@ impl_name_for_type (GbfProject  *_project,
 		return _("Script");
 	} else if (!strcmp (type, "info")) {
 		return _("Info Documentation");
+	} else if (!strcmp (type, "java")) {
+		return _("Java Module");
+	} else if (!strcmp (type, "python")) {
+		return _("Python Module");
 	} else {
 		return _("Unknown");
 	}
@@ -3357,6 +3362,10 @@ impl_mimetype_for_type (GbfProject  *_project,
 		return "text/x-sh";
 	} else if (!strcmp (type, "info")) {
 		return "application/x-tex-info";
+	} else if (!strcmp (type, "java")) {
+		return "application/x-java";
+	} else if (!strcmp (type, "python")) {
+		return "application/x-python";
 	} else {
 		return "text/plain";
 	}
@@ -3366,7 +3375,7 @@ static gchar **
 impl_get_types (GbfProject *_project)
 {
 	return g_strsplit ("program:shared_lib:static_lib:"
-			   "man:data:script:info", ":", 0);
+			   "man:data:script:info:java:python", ":", 0);
 }
 
 static GbfProjectTargetSource * 
@@ -3583,7 +3592,7 @@ impl_remove_source (GbfProject  *_project,
 	doc = xml_new_change_doc (project);
 	if (!xml_write_remove_source (project, doc, g_node)) {
 		error_set (error, GBF_PROJECT_ERROR_DOESNT_EXIST,
-			   _("Source coudn't be removed"));
+			   _("Source couldn't be removed"));
 		xmlFreeDoc (doc);
 		return;
 	}
