@@ -1923,9 +1923,7 @@ spawn_write_child (GIOChannel *ioc, GIOCondition condition, gpointer user_data)
 		data->input.length += bytes_written;
 
 		switch (status) {
-		    case G_IO_STATUS_NORMAL:
-			    DEBUG (g_message ("wrote %d bytes", bytes_written));
-			    
+		    case G_IO_STATUS_NORMAL:			    
 			    if (data->input.length < data->input.size) {
 				    /* don't remove the source */
 				    retval = TRUE;
